<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {
	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = 'theme1562';
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Logo type
	$logo_type = array("image_logo" => "Image Logo","text_logo" => "Text Logo");
	
	// Search box in the header
	$g_search_box = array("no" => "No","yes" => "Yes");
	
	// Background Defaults
	$background_defaults = array('color' => '', 'image' => '', 'repeat' => 'repeat','position' => 'top center','attachment'=>'scroll');
	
	// Superfish fade-in animation
	$sf_f_animation_array = array("show" => "Enable fade-in animation","false" => "Disable fade-in animation");
	
	// Superfish slide-down animation
	$sf_sl_animation_array = array("show" => "Enable slide-down animation","false" => "Disable slide-down animation");
	
	// Superfish animation speed
	$sf_speed_array = array("slow" => "Slow","normal" => "Normal", "fast" => "Fast");
	
	// Superfish arrows markup
	$sf_arrows_array = array("true" => "Yes","false" => "No");
	
	// Superfish shadows
	$sf_shadows_array = array("true" => "Yes","false" => "No");
	
	// Slider effects
	$sl_show_or_hide_array = array("true" => "Yes","false" => "No");
	// Slider effects
	$sl_effect_array = array("fade" => "Fade", "slide" => "Slide");
	
	// Slider Direction
	$sl_direction_array = array("horizontal" => "Horizontal", "vertical" => "Vertical");
	
	// Slideshow
	$sl_slideshow_array = array("true" => "Yes","false" => "No");
	
	// Slider keyboard nav
	$sl_keyboard_array = array("true" => "Yes","false" => "No");
	
	// Slider mousewheel
	$sl_mousewheel_array = array("true" => "Yes","false" => "No");
	
	// Slider randomize
	$sl_randomize_array = array("true" => "Yes","false" => "No");
	
	// Slider direct navigation
	$sl_dir_nav_array = array("true" => "Yes","false" => "No");
	
	// Slider control navigation
	$sl_control_nav_array = array("true" => "Yes","false" => "No");
	
	
	
	// Footer menu
	$footer_menu_array = array("true" => "Yes","false" => "No");
	
	// Featured image size on the blog.
	$post_image_size_array = array("thumbnail" => "Small size", "medium" => "Medium size", "large" => "Large size", "full" => "Full size");
	
	// Featured image size on the single page.
	$single_image_size_array = array("thumbnail" => "Small size", "medium" => "Medium size", "large" => "Large size", "full" => "Full size");
	
	// Meta for blog
	$post_meta_array = array("true" => "Yes","false" => "No");
	
	// Meta for blog
	$post_excerpt_array = array("true" => "Yes","false" => "No");
	
	// Testimonial
	$s_testimonial_array = array("true" => "Yes","false" => "No");
	
	// Portfolio
	$s_portfolio_array = array("true" => "Yes","false" => "No");
	
	
	
	
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_bloginfo('template_directory') . '/admin/images/';
		
	$options = array();
	
	$options[] = array( "name" => "General",
						"type" => "heading");
	
	$options[] = array( "name" =>  "Body styling",
						"desc" => "Change the background style.",
						"id" => "body_background",
						"std" => $background_defaults, 
						"type" => "background");
	
	$options[] = array( "name" => "Buttons and links color",
						"desc" => "Change the color of buttons and links.",
						"id" => "links_color",
						"std" => "",
						"type" => "color");
	
	$options[] = array( "name" => "Typography",
						"desc" => "Typography.",
						"id" => "example_typography",
						"std" => array('size' => '12px','face' => 'arial','style' => 'normal','color' => '#333'),
						"type" => "typography");
	
	$options[] = array( "name" => "Display search box?",
						"desc" => "Display search box in the header?",
						"id" => "g_search_box_id",
						"type" => "radio",
						"std" => "yes",
						"options" => $g_search_box);
	

	
	$options[] = array( "name" => "Logo & Social Links",
						"type" => "heading");
	
	
	$options[] = array( "name" => "Logo URL",
						"desc" => "Enter the direct path to your logo image. For example http://your_website_url_here.com",
						"id" => "logo_url",
						"type" => "upload");
						
	$options[] = array( "name" => "Facebook Links",
						"desc" => "Enter the Url. For example http://your_website_url_here.com",
						"id" => "fb_url",
						"type" => "text");

	$options[] = array( "name" => "Twitter Links",
						"desc" => "Enter the Url. For example http://your_website_url_here.com",
						"id" => "twi_url",
						"type" => "text");
						
	$options[] = array( "name" => "Linkedin Links",
						"desc" => "Enter the Url. For example http://your_website_url_here.com",
						"id" => "in_url",
						"type" => "text");
						
	$options[] = array( "name" => "Email Id",
						"desc" => "Enter the id. For example johan@test.com",
						"id" => "twi_url",
						"type" => "text");												
						
	
	$options[] = array( "name" => "Slider Settings",
						"type" => "heading");


	$options[] = array( "name" => "Show slider",
						"desc" => "Enable or desiable slider",
						"id" => "sl_show_or_hide",
						"std" => "true",
						"type" => "radio",
						"options" => $sl_show_or_hide_array);	
						
	if(of_get_option('sl_show_or_hide')=='true'){						

	$options[] = array( "name" => "Sliding effect",
						"desc" => "Select your animation type, 'fade' or 'slide'",
						"id" => "sl_effect",
						"std" => "fade",
						"type" => "select",
						"class" => "tiny", //mini, tiny, small
						"options" => $sl_effect_array);
						

	$options[] = array( "name" => "Slideshow",
						"desc" => "Animate slider automatically?",
						"id" => "sl_slideshow",
						"std" => "true",
						"type" => "radio",
						"options" => $sl_slideshow_array);	
	
	$options[] = array( "name" => "No of Slide Show",
						"desc" => "No of slides to show.",
						"id" => "sl_no_of_slide",
						"std" => "5",
						"class" => "mini",
						"type" => "text");
						
	$options[] = array( "name" => "Pause time",
						"desc" => "Pause time (ms).",
						"id" => "sl_pausetime",
						"std" => "7000",
						"class" => "mini",
						"type" => "text");
	
	$options[] = array( "name" => "Animation speed",
						"desc" => "Animation speed (ms).",
						"id" => "sl_animation_speed",
						"std" => "700",
						"class" => "mini",
						"type" => "text");
	
	$options[] = array( "name" => "Next & Prev navigation",
						"desc" => "Create navigation for previous/next navigation?",
						"id" => "sl_dir_nav",
						"std" => "true",
						"type" => "radio",
						"options" => $sl_dir_nav_array);
	
	$options[] = array( "name" => "Pagination",
						"desc" => "Create navigation for paging control of each clide? Note: Leave true for manualControls usage",
						"id" => "sl_control_nav",
						"std" => "true",
						"type" => "radio",
						"options" => $sl_control_nav_array);
	
	$options[] = array( "name" => "Keyboard",
						"desc" => "Allow slider navigating via keyboard left/right keys",
						"id" => "sl_keyboard",
						"std" => "true",
						"type" => "radio",
						"options" => $sl_keyboard_array);
	
	$options[] = array( "name" => "Mousewheel",
						"desc" => "Allow slider navigating via mousewheel",
						"id" => "sl_mousewheel",
						"std" => "false",
						"type" => "radio",
						"options" => $sl_mousewheel_array);
	
	$options[] = array( "name" => "Randomize",
						"desc" => "Randomize slide order?",
						"id" => "sl_randomize",
						"std" => "false",
						"type" => "radio",
						"options" => $sl_randomize_array);
							
	}

	
	
	/*$options[] = array( "name" => "Blog",
						"type" => "heading");
	

	$options[] = array( "name" => "Sidebar",
						"desc" => "Choose sidebar position.",
						"id" => "blog_sidebar_pos",
						"std" => "right",
						"type" => "images",
						"options" => array(
							'sideNone' => $imagepath . '1c.png',
							'sideLeft' => $imagepath . '2cl.png',
							'sideRight' => $imagepath . '2cr.png',)
						);
	
	$options[] = array( "name" => "Blog image size",
						"desc" => "Featured image size on the blog.",
						"id" => "post_image_size",
						"type" => "select",
						"std" => "normal",
						"class" => "small", //mini, tiny, small
						"options" => $post_image_size_array);
	
	$options[] = array( "name" => "Single post image size",
						"desc" => "Featured image size on the single page.",
						"id" => "single_image_size",
						"type" => "select",
						"std" => "normal",
						"class" => "small", //mini, tiny, small
						"options" => $single_image_size_array);
	
	$options[] = array( "name" => "Enable Meta for blog posts?",
						"desc" => "Enable or Disable meta information for blog posts.",
						"id" => "post_meta",
						"std" => "true",
						"type" => "radio",
						"options" => $post_meta_array);
	
	$options[] = array( "name" => "Enable excerpt for blog posts?",
						"desc" => "Enable or Disable excerpt for blog posts.",
						"id" => "post_excerpt",
						"std" => "true",
						"type" => "radio",
						"options" => $post_excerpt_array);*/
	
	
	
	
	$options[] = array( "name" => "Footer",
						"type" => "heading");
	
	$options[] = array( "name" => "Footer copyright text",
						"desc" => "Enter text used in the right side of the footer. HTML tags are allowed.",
						"id" => "footer_text",
						"std" => "",
						"type" => "textarea");
	
	$options[] = array( "name" => "Google Analytics Code",
						"desc" => "You can paste your Google Analytics or other tracking code in this box. This will be automatically added to the footer.",
						"id" => "ga_code",
						"std" => "",
						"type" => "textarea");
	
	$options[] = array( "name" => "Display Footer menu?",
						"desc" => "Do you want to display footer menu?",
						"id" => "footer_menu",
						"std" => "true",
						"type" => "radio",
						"options" => $footer_menu_array);
						
						
/*	$options[] = array( "name" => "Other",
						"type" => "heading");
						
	$options[] = array( "name" => "Show Testimonial",
						"desc" => "Enable or desiable Testimonial",
						"id" => "s_testimonial",
						"std" => "false",
						"type" => "radio",
						"options" => $s_testimonial_array);	

	$options[] = array( "name" => "No of Testimonial Show",
						"desc" => "No of Testimonial to show.",
						"id" => "sl_no_of_testi_slide",
						"std" => "3",
						"class" => "mini",
						"type" => "text");						

	$options[] = array( "name" => "Show Portfolio",
						"desc" => "Enable or desiable Portfolio",
						"id" => "s_portfolio",
						"std" => "false",
						"type" => "radio",
						"options" => $s_portfolio_array);												
	
	$options[] = array( "name" => "No of Portfolio Show",
						"desc" => "No of Portfolio to show.",
						"id" => "sl_no_of_pro_slide",
						"std" => "3",
						"class" => "mini",
						"type" => "text");*/
	
	return $options;
}

/* 
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});
	
	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}
	
	setradiopanel = function(name){
		if($('.section-radio input[name="'+name+'"]:eq(1)').is(':checked'))
				$($('.section-radio input[name="'+name+'"]').parents('.section-radio').get(0)).next().hide();
		
		$('.section-radio input[name="'+name+'"]').click(function(){
			if($(this).index() == 0)
			$($(this).parents('.section-radio').get(0)).next().slideDown('slow');
			else
			$($(this).parents('.section-radio').get(0)).next().slideUp('slow');
	})
		}
		setradiopanel('theme1562[s_testimonial]');
	   setradiopanel('theme1562[s_portfolio]')

	if($('.section-radio input[name="theme1562[sl_show_or_hide]"]:eq(1)').is(':checked'))
	$('.section-radio input[name="theme1562[sl_show_or_hide]"]').parents('.section-radio').siblings(':not(:first)').hide();
	
	$('.section-radio input[name="theme1562[sl_show_or_hide]"]').click(function(){
			if($(this).index() == 0)
			$(this).parents('.section-radio').siblings(':not(:first)').slideDown('slow');
			else
			$(this).parents('.section-radio').siblings(':not(:first)').slideUp('slow');
	})
	
});
</script>

<?php
}